@@ -9,14 +9,18 @@ if(isset($_SESSION['username'])) {
 try {
 	$dbh = new PDO(PDO_DNS, PDO_USER,PDO_PASS);
 
-	$sql = 'SELECT user_name,book_name,date FROM rental WHERE user_name LIKE :ID  ORDER BY date';
-
+	$sql = 'SELECT userid,book_name,date,rental_id FROM rental WHERE userid LIKE :ID  AND rental_flag IS NULL ORDER BY date';
 	$sth = $dbh->prepare($sql);
-	
 	$sth->bindValue(':ID',$_SESSION['userid']);
 	$sth->execute();
-
-	$book_array = $sth->fetchAll();
+	$book_array = $sth->fetchAll(PDO::FETCH_ASSOC);
+	
+	$sql = 'SELECT username FROM person WHERE userid LIKE :ID'; 
+	$sth = $dbh->prepare($sql);
+	$sth->bindValue(':ID',$_SESSION['userid']);
+	$sth->execute();
+	$username = $sth->fetch(PDO::FETCH_ASSOC);
+	
 
 	$day = new Myday();
 	
@@ -57,13 +61,14 @@ $dbh = null;
 
 /*smarty*/
 
-
 $smarty->assign("title","TOP"); //headerのtitle
 $smarty->assign("pagename","index");//pageの名前
 $smarty->assign("book_count",$book_count);
-$smarty->assign("book_data",$book_array);
+$smarty->assign("book_data",$book_array);//DBから取得した本のレンタルデータ
+
 $smarty->assign("session_status",$session->getstatus());
 $smarty->assign("over_book",$over_book);
+$smarty->assign("username",$username['username']);
 
 $smarty->display("index.tpl");
 
