@@ -3,17 +3,24 @@
 
 require("../require.php");
 $session=new Mysession("CONTINUE",false,false); 
-#$session->setdata("TEST","tekitou");
-//ログアウト処理
-#$session->sessionempty();
-
 if($_GET['flag']=="logout") {
 	$session->stop();
 }
-
 //continueによってページを切り替える
-if(isset($_GET['continue'])){
-	header("Location:".$_GET['continue'] );
+//会員登録するページだったらTOPページへ飛ぶ
+
+$continue = $_GET['continue'];
+$pat = '/entry/';
+
+if(preg_match($pat,$continue)){
+	$flag = false;
+}
+
+
+
+if(isset($continue) && $flag){
+
+	header("Location:http://localhost". $continue);
 	exit;
 }  else  {
 	header("Location: index.php");
