@@ -1,4 +1,4 @@
-<?php /* Smarty version 2.6.20, created on 2009-01-25 20:48:24
+<?php /* Smarty version 2.6.20, created on 2009-01-26 14:27:46
          compiled from index_login.tpl */ ?>
 <div id="column2_main">
 		
@@ -8,7 +8,7 @@
 <div id="index_search_login">
 		
 		<?php if ($this->_tpl_vars['over_book'] == true): ?>
-		<?php echo $_SESSION['username']; ?>
+		<?php echo $this->_tpl_vars['username']; ?>
 さんの返却期限が切れている本 <br />
 		<p>	
 		<?php unset($this->_sections['i']);
@@ -72,7 +72,7 @@ $this->_sections['i']['last']       = ($this->_sections['i']['iteration'] == $th
 
 		<div id="right_column">
 
-		<h3> <?php echo $_SESSION['username']; ?>
+		<h3> <?php echo $this->_tpl_vars['username']; ?>
 さんの借りている本	</h3>
 		
 		<table border=3px>
@@ -104,11 +104,10 @@ $this->_sections['i']['index_next'] = $this->_sections['i']['index'] + $this->_s
 $this->_sections['i']['first']      = ($this->_sections['i']['iteration'] == 1);
 $this->_sections['i']['last']       = ($this->_sections['i']['iteration'] == $this->_sections['i']['total']);
 ?>
-		<form action="return1.php?name=Fast CakePHP" method="GET">
+		<form action="return_confirm.php" method="POST">
 		<tr>
 
-			<td> <a href="book_info.php?name=<?php echo $this->_tpl_vars['book_data'][$this->_sections['i']['index']]['book_name']; ?>
-"> <?php echo $this->_tpl_vars['book_data'][$this->_sections['i']['index']]['book_name']; ?>
+			<td> <a href="book_info.php"> <?php echo $this->_tpl_vars['book_data'][$this->_sections['i']['index']]['book_name']; ?>
  </a> </td>		
 			
 			<?php if ($this->_tpl_vars['book_data'][$this->_sections['i']['index']]['over'] == 'true'): ?>
@@ -120,7 +119,15 @@ $this->_sections['i']['last']       = ($this->_sections['i']['iteration'] == $th
 			<?php echo $this->_tpl_vars['book_data'][$this->_sections['i']['index']]['date']; ?>
 </td> 
 		
-			<td> <input type="submit" value="返却する"> </td>
+
+			<td> 
+			<input type="hidden" value="<?php echo $this->_tpl_vars['book_data'][$this->_sections['i']['index']]['book_name']; ?>
+" name="book_name">
+			<input type="hidden" value="<?php echo $this->_tpl_vars['book_data'][$this->_sections['i']['index']]['rental_id']; ?>
+" name="rental_id">
+			<input type="submit" value="返却する"> 
+			
+			</td>
 		</tr>
 		</form>
 		<?php endfor; endif; ?>
