@@ -1,12 +1,10 @@
-<?php /* Smarty version 2.6.20, created on 2008-11-26 10:53:55
+<?php /* Smarty version 2.6.20, created on 2009-01-26 14:55:32
          compiled from return.tpl */ ?>
-<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Transitional//EN" "http://www.w3.org/TR/xhtml1/DTD/xhtml1-transitional.dtd">
-<html xmlns="http://www.w3.org/1999/xhtml">
-<head>
-<meta http-equiv="Content-Type" content="text/html; charset=shift_jis" />
-<title>[LIBJO]781実習室図書システム-返却</title>
-<link rel="stylesheet" href="../css/version1.css" type="text/css" />
-</head>
+<?php $_smarty_tpl_vars = $this->_tpl_vars;
+$this->_smarty_include(array('smarty_include_tpl_file' => "DTD.tpl", 'smarty_include_vars' => array()));
+$this->_tpl_vars = $_smarty_tpl_vars;
+unset($_smarty_tpl_vars);
+ ?>
 <body>
 <!--全体-->
 <div id="wrapper">
@@ -25,6 +23,7 @@ unset($_smarty_tpl_vars);
 	    <p align="center">【<?php echo $this->_tpl_vars['book_name']; ?>
 の返却を確認致しました】</p>
 	    <p align="center">ご利用ありがとうございました。</p>
+	    <p align="center"><a href="index.php?reset=yes">TOPへ戻る</a></p>
 	  </div>
 	  </div>
 	</div>
